==> huaweicloudsdkvpc-3.1.123-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/list_clouddcn_subnets_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListClouddcnSubnetsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'clouddcn_subnets': 'list[ClouddcnSubnet]'
    }

    attribute_map = {
        'clouddcn_subnets': 'clouddcn_subnets'
    }

    def __init__(self, clouddcn_subnets=None):
        """ListClouddcnSubnetsResponse

        The model defined in huaweicloud sdk

        :param clouddcn_subnets: clouddcn subnet对象列表
        :type clouddcn_subnets: list[:class:`huaweicloudsdkvpc.v3.ClouddcnSubnet`]
        """
        
        super(ListClouddcnSubnetsResponse, self).__init__()

        self._clouddcn_subnets = None
        self.discriminator = None

        if clouddcn_subnets is not None:
            self.clouddcn_subnets = clouddcn_subnets

    @property
    def clouddcn_subnets(self):
        """Gets the clouddcn_subnets of this ListClouddcnSubnetsResponse.

        clouddcn subnet对象列表

        :return: The clouddcn_subnets of this ListClouddcnSubnetsResponse.
        :rtype: list[:class:`huaweicloudsdkvpc.v3.ClouddcnSubnet`]
        """
        return self._clouddcn_subnets

    @clouddcn_subnets.setter
    def clouddcn_subnets(self, clouddcn_subnets):
        """Sets the clouddcn_subnets of this ListClouddcnSubnetsResponse.

        clouddcn subnet对象列表

        :param clouddcn_subnets: The clouddcn_subnets of this ListClouddcnSubnetsResponse.
        :type clouddcn_subnets: list[:class:`huaweicloudsdkvpc.v3.ClouddcnSubnet`]
        """
        self._clouddcn_subnets = clouddcn_subnets

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListClouddcnSubnetsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvpc-3.1.150-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/list_clouddcn_subnets_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListClouddcnSubnetsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'clouddcn_subnets': 'list[ClouddcnSubnet]'
    }

    attribute_map = {
        'clouddcn_subnets': 'clouddcn_subnets'
    }

    def __init__(self, clouddcn_subnets=None):
        r"""ListClouddcnSubnetsResponse

        The model defined in huaweicloud sdk

        :param clouddcn_subnets: clouddcn subnet对象列表
        :type clouddcn_subnets: list[:class:`huaweicloudsdkvpc.v3.ClouddcnSubnet`]
        """
        
        super(ListClouddcnSubnetsResponse, self).__init__()

        self._clouddcn_subnets = None
        self.discriminator = None

        if clouddcn_subnets is not None:
            self.clouddcn_subnets = clouddcn_subnets

    @property
    def clouddcn_subnets(self):
        r"""Gets the clouddcn_subnets of this ListClouddcnSubnetsResponse.

        clouddcn subnet对象列表

        :return: The clouddcn_subnets of this ListClouddcnSubnetsResponse.
        :rtype: list[:class:`huaweicloudsdkvpc.v3.ClouddcnSubnet`]
        """
        return self._clouddcn_subnets

    @clouddcn_subnets.setter
    def clouddcn_subnets(self, clouddcn_subnets):
        r"""Sets the clouddcn_subnets of this ListClouddcnSubnetsResponse.

        clouddcn subnet对象列表

        :param clouddcn_subnets: The clouddcn_subnets of this ListClouddcnSubnetsResponse.
        :type clouddcn_subnets: list[:class:`huaweicloudsdkvpc.v3.ClouddcnSubnet`]
        """
        self._clouddcn_subnets = clouddcn_subnets

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListClouddcnSubnetsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
